@@ -1,7 +1,7 @@
 package Pod::Elide;
 
-our $DATE = '2017-01-28'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-29'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,14 +12,23 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(elide);
 
 sub _markup {
-    my ($cmd, $rest) = @_;
+    my ($preamble, $cmd, $postamble, $opts) = @_;
 
-    my $prio = 10;
+    my $retain_level = $opts->{retain_level} // 9;
+
+    my $prio;
     if ($cmd =~ /\Ahead(\d+)\z/) {
-        $prio = $1;
+        $prio = $1 if $retain_level >= $1;
+    }
+    unless (defined $prio) {
+        $prio = $retain_level >= 9 ? 10 : 999;
     }
 
-    "<elspan prio=$prio>=$cmd$rest</elspan>";
+    if ($prio < 999) {
+        "$preamble<elspan prio=$prio>=$cmd$postamble</elspan>";
+    } else {
+        "$preamble$cmd$postamble";
+    }
 }
 
 sub elide {
@@ -29,9 +38,13 @@ sub elide {
 
     $opts //= {};
 
-    $str =~ s/^=(\w+)(.*\R(?:\R|\z))/_markup($1, $2)/egm;
+    $str =~ s/^(\A|\R)=(\w+)(.*\R(?:\R|\z))/_markup($1, $2, $3, $opts)/egm;
     #print $str;
-    String::Elide::Lines::elide($str, $len, {%$opts, default_prio=>999});
+    String::Elide::Lines::elide($str, $len, {
+        marker => ["\n", ($opts->{marker} // "..")."\n", "\n"],
+        truncate => $opts->{truncate} // 'bottom',
+        default_prio=>999,
+    });
 }
 
 1;
@@ -49,7 +62,7 @@ Pod::Elide - Elide POD lines from a string, with options
 
 =head1 VERSION
 
-This document describes version 0.002 of Pod::Elide (from Perl distribution Pod-Elide), released on 2017-01-28.
+This document describes version 0.003 of Pod::Elide (from Perl distribution Pod-Elide), released on 2017-01-29.
 
 =head1 SYNOPSIS
 
@@ -142,6 +155,8 @@ Known options:
 
 =item * truncate => 'top'|'middle'|'bottom'|'ends' (default: 'bottom')
 
+=item * retain_level => int (1|2|3|9, default: 9)
+
 =back
 
 =head1 HOMEPAGE
